#
#  Roundcube database cleaning: finally removes all records that are
#  marked as deleted.
#
# m h  dom mon dow user     command
0   5  *   *   *   www-data test -x /usr/share/roundcube/bin/cleandb.sh && /usr/share/roundcube/bin/cleandb.sh >/dev/null
